import { BaseWalletAdapter, EventEmitter, SendTransactionOptions, WalletName, WalletReadyState } from "@solana/wallet-adapter-base";
import { Connection, Keypair, PublicKey, SendOptions, Transaction, TransactionSignature } from "@solana/web3.js";
interface E2EWalletEvents {
    connect(...args: unknown[]): unknown;
    disconnect(...args: unknown[]): unknown;
}
interface E2EWallet extends EventEmitter<E2EWalletEvents> {
    publicKey?: {
        toBytes(): Uint8Array;
    };
    isConnected: boolean;
    signTransaction(transaction: Transaction): Promise<Transaction>;
    signAllTransactions(transactions: Transaction[]): Promise<Transaction[]>;
    signAndSendTransaction(transaction: Transaction, options?: SendOptions): Promise<{
        signature: TransactionSignature;
    }>;
    signMessage(message: Uint8Array): Promise<{
        signature: Uint8Array;
    }>;
    connect(): Promise<void>;
    disconnect(): Promise<void>;
}
export interface E2EWindow extends Window {
    solanaE2E?: E2EWalletAdapter;
}
export interface E2EWalletAdapterConfig {
    keypair?: Keypair;
}
export declare const E2EWalletName: WalletName<"E2E">;
export declare class E2EWalletAdapter extends BaseWalletAdapter {
    name: WalletName<"E2E">;
    url: string;
    icon: string;
    _connecting: boolean;
    _wallet: E2EWallet | null;
    _publicKey: PublicKey | null;
    _underlyingWallet: Keypair;
    _readyState: WalletReadyState;
    _approveNext: boolean;
    constructor(config?: E2EWalletAdapterConfig);
    get publicKey(): PublicKey;
    get connecting(): boolean;
    get connected(): boolean;
    get readyState(): WalletReadyState;
    rejectNext(): void;
    _checkForReject(): void;
    connect(): Promise<void>;
    disconnect(): Promise<void>;
    sendTransaction(transaction: Transaction, connection: Connection, options?: SendTransactionOptions): Promise<TransactionSignature>;
    signTransaction(transaction: Transaction): Promise<Transaction>;
    signAllTransactions(transactions: Transaction[]): Promise<Transaction[]>;
}
export {};
